==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/template/ContainerTemplateBuilder.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerTemplateBuilder extends ContainerTemplateFluentImpl<ContainerTemplateBuilder> implements VisitableBuilder<ContainerTemplate,ContainerTemplateBuilder>{

    ContainerTemplateFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerTemplateBuilder(){
            this(true);
    }
    public ContainerTemplateBuilder(Boolean validationEnabled){
            this(new ContainerTemplate(), validationEnabled);
    }
    public ContainerTemplateBuilder(ContainerTemplateFluent<?> fluent){
            this(fluent, true);
    }
    public ContainerTemplateBuilder(ContainerTemplateFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ContainerTemplate(), validationEnabled);
    }
    public ContainerTemplateBuilder(ContainerTemplateFluent<?> fluent,ContainerTemplate instance){
            this(fluent, instance, true);
    }
    public ContainerTemplateBuilder(ContainerTemplateFluent<?> fluent,ContainerTemplate instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withEnv(instance.getEnv());

            this.validationEnabled = validationEnabled; 
    }
    public ContainerTemplateBuilder(ContainerTemplate instance){
            this(instance,true);
    }
    public ContainerTemplateBuilder(ContainerTemplate instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withEnv(instance.getEnv());

            this.validationEnabled = validationEnabled; 
    }

    public ContainerTemplate build(){
            ContainerTemplate buildable = new ContainerTemplate();
            buildable.setEnv(fluent.getEnv());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerTemplateBuilder that = (ContainerTemplateBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/template/ContainerTemplateBuilder.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerTemplateBuilder extends ContainerTemplateFluentImpl<ContainerTemplateBuilder> implements VisitableBuilder<ContainerTemplate,ContainerTemplateBuilder>{

    ContainerTemplateFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerTemplateBuilder(){
            this(true);
    }
    public ContainerTemplateBuilder(Boolean validationEnabled){
            this(new ContainerTemplate(), validationEnabled);
    }
    public ContainerTemplateBuilder(ContainerTemplateFluent<?> fluent){
            this(fluent, true);
    }
    public ContainerTemplateBuilder(ContainerTemplateFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ContainerTemplate(), validationEnabled);
    }
    public ContainerTemplateBuilder(ContainerTemplateFluent<?> fluent,ContainerTemplate instance){
            this(fluent, instance, true);
    }
    public ContainerTemplateBuilder(ContainerTemplateFluent<?> fluent,ContainerTemplate instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withEnv(instance.getEnv());

            fluent.withSecurityContext(instance.getSecurityContext());

            this.validationEnabled = validationEnabled; 
    }
    public ContainerTemplateBuilder(ContainerTemplate instance){
            this(instance,true);
    }
    public ContainerTemplateBuilder(ContainerTemplate instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withEnv(instance.getEnv());

            this.withSecurityContext(instance.getSecurityContext());

            this.validationEnabled = validationEnabled; 
    }

    public ContainerTemplate build(){
            ContainerTemplate buildable = new ContainerTemplate();
            buildable.setEnv(fluent.getEnv());
            buildable.setSecurityContext(fluent.getSecurityContext());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerTemplateBuilder that = (ContainerTemplateBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
